@@ -20,7 +20,6 @@ import shutil
 import stat
 from sys import maxsize
 import time
-from unittest import SkipTest
 from urllib.parse import urlsplit, urlunsplit
 import warnings
 
@@ -38,6 +37,7 @@ if TYPE_CHECKING:
     from git.remote import Remote
     from git.repo.base import Repo
     from git.config import GitConfigParser, SectionConstraint
+    from git import Git
     # from git.objects.base import IndexObject
 
 
@@ -69,7 +69,7 @@ from gitdb.util import (  # NOQA @IgnorePep8
 # Most of these are unused here, but are for use by git-python modules so these
 # don't see gitdb all the time. Flake of course doesn't like it.
 __all__ = ["stream_copy", "join_path", "to_native_path_linux",
-           "join_path_native", "Stats", "IndexFileSHA1Writer", "Iterable", "IterableList",
+           "join_path_native", "Stats", "IndexFileSHA1Writer", "IterableObj", "IterableList",
            "BlockingLockFile", "LockFile", 'Actor', 'get_user_id', 'assure_directory_exists',
            'RemoteProgress', 'CallableRemoteProgress', 'rmtree', 'unbare_repo',
            'HIDE_WINDOWS_KNOWN_ERRORS']
@@ -129,6 +129,7 @@ def rmtree(path: PathLike) -> None:
             func(path)  # Will scream if still not possible to delete.
         except Exception as ex:
             if HIDE_WINDOWS_KNOWN_ERRORS:
+                from unittest import SkipTest
                 raise SkipTest("FIXME: fails with: PermissionError\n  {}".format(ex)) from ex
             raise
 
@@ -379,7 +380,7 @@ def get_user_id() -> str:
     return "%s@%s" % (getpass.getuser(), platform.node())
 
 
-def finalize_process(proc: subprocess.Popen, **kwargs: Any) -> None:
+def finalize_process(proc: Union[subprocess.Popen, 'Git.AutoInterrupt'], **kwargs: Any) -> None:
     """Wait for the process (clone, fetch, pull or push) and handle its errors accordingly"""
     # TODO: No close proc-streams??
     proc.wait(**kwargs)
@@ -403,12 +404,12 @@ def expand_path(p: Union[None, PathLike], expand_vars: bool = True) -> Optional[
         p = osp.expanduser(p)  # type: ignore
         if expand_vars:
             p = osp.expandvars(p)    # type: ignore
-        return osp.normpath(osp.abspath(p))    # type: ignore
+        return osp.normpath(osp.abspath(p))  # type: ignore
     except Exception:
         return None
 
 
-def remove_password_if_present(cmdline):
+def remove_password_if_present(cmdline: Sequence[str]) -> List[str]:
     """
     Parse any command line argument and if on of the element is an URL with a
     password, replace it by stars (in-place).
@@ -704,7 +705,11 @@ class Actor(object):
                 setattr(actor, attr, val)
             except KeyError:
                 if config_reader is not None:
-                    setattr(actor, attr, config_reader.get_value('user', cvar, default()))
+                    try:
+                        val = config_reader.get('user', cvar)
+                    except Exception:
+                        val = default()
+                    setattr(actor, attr, val)
                 # END config-reader handling
                 if not getattr(actor, attr):
                     setattr(actor, attr, default())
@@ -1033,7 +1038,7 @@ class IterableList(List[T_IterableObj]):
 
 class IterableClassWatcher(type):
     """ Metaclass that watches """
-    def __init__(cls, name, bases, clsdict):
+    def __init__(cls, name: str, bases: Tuple, clsdict: Dict) -> None:
         for base in bases:
             if type(base) == IterableClassWatcher:
                 warnings.warn(f"GitPython Iterable subclassed by {name}. "
@@ -1052,7 +1057,7 @@ class Iterable(metaclass=IterableClassWatcher):
     _id_attribute_ = "attribute that most suitably identifies your instance"
 
     @classmethod
-    def list_items(cls, repo, *args, **kwargs):
+    def list_items(cls, repo: 'Repo', *args: Any, **kwargs: Any) -> Any:
         """
         Deprecated, use IterableObj instead.
         Find all items of this type - subclasses can specify args and kwargs differently.
@@ -1062,7 +1067,7 @@ class Iterable(metaclass=IterableClassWatcher):
         :note: Favor the iter_items method as it will
 
         :return:list(Item,...) list of item instances"""
-        out_list = IterableList(cls._id_attribute_)
+        out_list: Any = IterableList(cls._id_attribute_)
         out_list.extend(cls.iter_items(repo, *args, **kwargs))
         return out_list
 
